@@ -1,4 +1,4 @@
-# $Id: Stag.pm,v 1.39 2005/12/16 17:42:44 cmungall Exp $
+# $Id: Stag.pm,v 1.41 2007/10/15 04:08:45 cmungall Exp $
 # -------------------------------------------------------
 #
 # Copyright (C) 2004 Chris Mungall <cjm@fruitfly.org>
@@ -21,7 +21,7 @@ use Carp;
 use Data::Stag::Base;
 
 use vars qw($VERSION);
-$VERSION="0.10";
+$VERSION="0.11";
 
 @AUTOMETHODS = qw(
                   new
@@ -1700,6 +1700,23 @@ into this
    (pet
     (name "fluffy")))
 
+=head3 maptree
+
+       Title: maptree
+
+        Args: CODE
+      Return: Node[]
+     Example: $data->maptree(sub {
+				 my $stag = shift;
+				 my $parent = shift;
+				 if ($stag->element eq 'pet') {
+				     [pet=>$stag->sget_foo]
+				 }
+                                 else {
+				     $stag
+                                 }
+			     });
+
 =head2 MISCELLANEOUS METHODS
 
 
